'use strict';

var webhooksMethods = require('@octokit/webhooks-methods');

function createGithubSignatureValidator(config) {
  const secret = config.getOptionalString(
    "events.modules.github.webhookSecret"
  );
  if (!secret) {
    return void 0;
  }
  return async (request, context) => {
    const signature = request.headers["x-hub-signature-256"];
    if (!signature || !await webhooksMethods.verify(
      secret,
      request.raw.body.toString(request.raw.encoding),
      signature
    )) {
      context.reject({
        status: 403,
        payload: { message: "invalid signature" }
      });
    }
  };
}

exports.createGithubSignatureValidator = createGithubSignatureValidator;
//# sourceMappingURL=createGithubSignatureValidator.cjs.js.map
